from .character_search import CharacterSearch
from .timeline import Timeline
from .status import Status
from .equipments import Equipments
from .avatars import Avatars
from .others import Others
from .buff import Buff


import urllib.parse
from .functions import get_request
from .METADATA import SERVER_NAME_2_ID

class CharacterSearch():
    
    def __init__(self, arg_api_key : str):
        """
        클래스 생성 시 Neople Open API key를 입력받는다
            Args :
                arg_api_key(str) : Neople Open API key
        """        
        self.__api_key = arg_api_key
    
    def get_data(self, arg_server_name : str, arg_character_name : str):
        """
        서버명과 캐릭터 이름을 검색하면 기본 정보를 반환
            Args : 
                arg_server_name(str) : 서버 이름 ex) 디레지에
                
                arg_character_name(str) : 캐릭터 이름 ex) 홍길동
        """

        # 한글 서버명을 영문 서버명으로 변환
        arg_server_name = SERVER_NAME_2_ID[arg_server_name]
        
        url = f"https://api.neople.co.kr/df/servers/{arg_server_name}/characters?characterName={urllib.parse.quote(arg_character_name)}&limit=1&apikey={self.__api_key}"
        data = get_request(url)
        data = data['rows'][0]

        self.server_id = data['serverId']
        self.character_name = data['characterName']
        self.character_id = data['characterId']
        self.job_name = data['jobName'] 
        self.job_grow_name = data['jobGrowName']
        self.level = data['level']


from .functions import get_request, one_slot
from .METADATA import EQUIPMENT_LIST, AVATAR_LIST, PLATINUM_AVATAR_LIST

class BuffAvatar():
    def __init__(self):
        self.item_name = None
    def get_buff_avatar_data(self, arg_avatar_dict):
        try: 
            self.item_name = arg_avatar_dict['itemName']
        except:
            pass
class BuffPlatimun(BuffAvatar):
    def __init__(self):
        super().__init__()    
        self.option = None
        self.platinum = None
    
    def get_buff_avatar_data(self, arg_avatar_dict):
        super().get_buff_avatar_data(arg_avatar_dict)
        try:
            self.option = arg_avatar_dict['optionAbility']
        except:
            pass
        try:    
            self.platinum = arg_avatar_dict['emblems'][0]['itemName']
        except:
            pass    

class Buff():
    def __init__(self, arg_api_key):
        """
        클래스 생성 시 Neople Open API key를 입력받는다
            Args :
                arg_api_key(str) : Neople Open API key
        """        
        self.__api_key = arg_api_key    
        self.buff_level = None
        self.buff_desc = None
        for equipment in EQUIPMENT_LIST:
            exec(f"self.buff_equipment_{equipment} = None")
        for avatar in list(set(AVATAR_LIST) - set(PLATINUM_AVATAR_LIST)):
            exec(f"self.buff_avatar_{avatar} = BuffAvatar()")
        for avatar in PLATINUM_AVATAR_LIST:
            exec(f"self.buff_avatar_{avatar} = BuffPlatimun()")
        self.buff_creature = None           
    
    def get_data(self, arg_server_id : str, arg_character_id : str):
        data = get_request(f"https://api.neople.co.kr/df/servers/{arg_server_id}/characters/{arg_character_id}/skill/buff/equip/equipment?apikey={self.__api_key}")
        data = data['skill']['buff']
        
        if data:
            for index, value in enumerate(data['skillInfo']['option']['values']):
                data['skillInfo']['option']['desc'] = data['skillInfo']['option']['desc'].replace("{" + f"value{index + 1}" + "}", value)
            self.buff_level = data['skillInfo']['option']['level']
            self.buff_desc = data['skillInfo']['option']['desc']
        if data:
            data = data['equipment']
        if data:
            for equipment in EQUIPMENT_LIST:
                try:    
                    exec(f"self.buff_{equipment} = one_slot(data, '{equipment.upper()}')['itemName']")
                except:
                    pass    
        
        data = get_request(f"https://api.neople.co.kr/df/servers/{arg_server_id}/characters/{arg_character_id}/skill/buff/equip/avatar?apikey={self.__api_key}")
        data = data['skill']['buff']
        if data:
            data = data['avatar']
        if data:
            for avatar in AVATAR_LIST:            
                try:
                    exec(f"self.buff_avatar_{avatar}.get_buff_avatar_data(one_slot(data, '{avatar.upper()}'))") 
                except:
                    pass    
        data = get_request(f"https://api.neople.co.kr/df/servers/{arg_server_id}/characters/{arg_character_id}/skill/buff/equip/creature?apikey={self.__api_key}")
        data = data['skill']['buff']
        if data:
            self.buff_creature = data['creature'][0]['itemName']
